@@ -1,4 +1,5 @@
 import abc
+import sys
 
 import pytest
 
@@ -40,7 +41,16 @@ def test_model_subclassing_abstract_base_classes_without_implementation_raises_e
 
     with pytest.raises(TypeError) as excinfo:
         Model(some_field='some_value')
-    assert str(excinfo.value) == (
-        "Can't instantiate abstract class Model with abstract methods "
-        "my_abstract_classmethod, my_abstract_method, my_abstract_property, my_abstract_staticmethod"  # noqa: Q000
-    )
+
+    if sys.version_info < (3, 12):
+        message = (
+            "Can't instantiate abstract class Model with abstract methods "
+            "my_abstract_classmethod, my_abstract_method, my_abstract_property, my_abstract_staticmethod"  # noqa: Q000
+        )
+    else:
+        message = (
+            "Can't instantiate abstract class Model without an implementation for abstract methods "
+            "'my_abstract_classmethod', 'my_abstract_method', 'my_abstract_property', 'my_abstract_staticmethod'"
+        )
+
+    assert str(excinfo.value) == message
